Module: Aws::PartnerCentralAccount::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-partnercentralaccount/errors.rb
Overview
When PartnerCentralAccount returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::PartnerCentralAccount::Errors::ServiceError < Errors::ServiceError
You can rescue all PartnerCentralAccount errors using ServiceError:
begin
# do stuff
rescue Aws::PartnerCentralAccount::Errors::ServiceError
# rescues all PartnerCentralAccount API errors
end
## Request Context ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
## Error Classes
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AccessDeniedException, ConflictException, InternalServerException, ResourceNotFoundException, ServiceQuotaExceededException, ThrottlingException, ValidationException