Class: Aws::PartnerCentralAccount::Types::AcceptConnectionInvitationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralaccount/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

The catalog identifier where the connection invitation exists.

Returns:

  • (String)


31
32
33
34
35
36
37
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 31

class AcceptConnectionInvitationRequest < Struct.new(
  :catalog,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


31
32
33
34
35
36
37
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 31

class AcceptConnectionInvitationRequest < Struct.new(
  :catalog,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the connection invitation to accept.

Returns:

  • (String)


31
32
33
34
35
36
37
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 31

class AcceptConnectionInvitationRequest < Struct.new(
  :catalog,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end