Class: Aws::PartnerCentralAccount::Types::CancelConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralaccount/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

The catalog identifier where the connection exists.

Returns:

  • (String)


380
381
382
383
384
385
386
387
388
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 380

class CancelConnectionRequest < Struct.new(
  :catalog,
  :identifier,
  :connection_type,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


380
381
382
383
384
385
386
387
388
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 380

class CancelConnectionRequest < Struct.new(
  :catalog,
  :identifier,
  :connection_type,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of connection to cancel (e.g., reseller, distributor, technology partner).

Returns:

  • (String)


380
381
382
383
384
385
386
387
388
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 380

class CancelConnectionRequest < Struct.new(
  :catalog,
  :identifier,
  :connection_type,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the connection to cancel.

Returns:

  • (String)


380
381
382
383
384
385
386
387
388
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 380

class CancelConnectionRequest < Struct.new(
  :catalog,
  :identifier,
  :connection_type,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason for canceling the connection, providing context for the termination.

Returns:

  • (String)


380
381
382
383
384
385
386
387
388
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 380

class CancelConnectionRequest < Struct.new(
  :catalog,
  :identifier,
  :connection_type,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end