Class: Aws::PartnerCentralAccount::Types::ErrorDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralaccount/types.rb

Overview

Contains detailed information about an error that occurred during an operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#localeString

The locale or language code for the error message.

Returns:

  • (String)


1026
1027
1028
1029
1030
1031
1032
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1026

class ErrorDetail < Struct.new(
  :locale,
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A human-readable description of the error.

Returns:

  • (String)


1026
1027
1028
1029
1030
1031
1032
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1026

class ErrorDetail < Struct.new(
  :locale,
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

A machine-readable code or reason for the error.

Returns:

  • (String)


1026
1027
1028
1029
1030
1031
1032
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1026

class ErrorDetail < Struct.new(
  :locale,
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end