Class: Aws::PartnerCentralAccount::Types::ListConnectionInvitationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralaccount/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog ⇒ String

The catalog identifier for the partner account.

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835

class ListConnectionInvitationsRequest < Struct.new(
  :catalog,
  :next_token,
  :connection_type,
  :max_results,
  :other_participant_identifiers,
  :participant_type,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#connection_type ⇒ String

Filter results by connection type (e.g., reseller, distributor, technology partner).

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835

class ListConnectionInvitationsRequest < Struct.new(
  :catalog,
  :next_token,
  :connection_type,
  :max_results,
  :other_participant_identifiers,
  :participant_type,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of connection invitations to return in a single response.

Returns:

  • (Integer)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835

class ListConnectionInvitationsRequest < Struct.new(
  :catalog,
  :next_token,
  :connection_type,
  :max_results,
  :other_participant_identifiers,
  :participant_type,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token for retrieving the next page of results in paginated responses.

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835

class ListConnectionInvitationsRequest < Struct.new(
  :catalog,
  :next_token,
  :connection_type,
  :max_results,
  :other_participant_identifiers,
  :participant_type,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#other_participant_identifiers ⇒ Array<String>

Filter results by specific participant identifiers.

Returns:

  • (Array<String>)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835

class ListConnectionInvitationsRequest < Struct.new(
  :catalog,
  :next_token,
  :connection_type,
  :max_results,
  :other_participant_identifiers,
  :participant_type,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#participant_type ⇒ String

Filter results by participant type (inviter or invitee).

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835

class ListConnectionInvitationsRequest < Struct.new(
  :catalog,
  :next_token,
  :connection_type,
  :max_results,
  :other_participant_identifiers,
  :participant_type,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Filter results by invitation status (pending, accepted, rejected, canceled, expired).

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835

class ListConnectionInvitationsRequest < Struct.new(
  :catalog,
  :next_token,
  :connection_type,
  :max_results,
  :other_participant_identifiers,
  :participant_type,
  :status)
  SENSITIVE = []
  include Aws::Structure
end