Class: Aws::PartnerCentralAccount::Types::ListConnectionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::ListConnectionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_summaries ⇒ Array<Types::ConnectionSummary>
A list of connection summaries matching the specified criteria.
-
#next_token ⇒ String
The token for retrieving the next page of results if more results are available.
Instance Attribute Details
#connection_summaries ⇒ Array<Types::ConnectionSummary>
A list of connection summaries matching the specified criteria.
1911 1912 1913 1914 1915 1916 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1911 class ListConnectionsResponse < Struct.new( :connection_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results if more results are available.
1911 1912 1913 1914 1915 1916 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1911 class ListConnectionsResponse < Struct.new( :connection_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |