Class: Aws::PartnerCentralAccount::Types::ListPartnersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::ListPartnersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
The catalog identifier to list partners from.
-
#next_token ⇒ String
The token for retrieving the next page of results in paginated responses.
Instance Attribute Details
#catalog ⇒ String
The catalog identifier to list partners from.
1929 1930 1931 1932 1933 1934 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1929 class ListPartnersRequest < Struct.new( :catalog, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results in paginated responses.
1929 1930 1931 1932 1933 1934 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1929 class ListPartnersRequest < Struct.new( :catalog, :next_token) SENSITIVE = [] include Aws::Structure end |