Class: Aws::PartnerCentralAccount::Types::ListPartnersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::ListPartnersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for retrieving the next page of results if more results are available.
-
#partner_summary_list ⇒ Array<Types::PartnerSummary>
A list of partner summaries including basic information about each partner account.
Instance Attribute Details
#next_token ⇒ String
The token for retrieving the next page of results if more results are available.
1948 1949 1950 1951 1952 1953 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1948 class ListPartnersResponse < Struct.new( :partner_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#partner_summary_list ⇒ Array<Types::PartnerSummary>
A list of partner summaries including basic information about each partner account.
1948 1949 1950 1951 1952 1953 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1948 class ListPartnersResponse < Struct.new( :partner_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |