Class: Aws::PartnerCentralAccount::Types::PartnerProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::PartnerProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Contains comprehensive profile information for a partner including public-facing details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the partner's business, services, and capabilities.
-
#display_name ⇒ String
The public display name for the partner organization.
-
#headquarters ⇒ Types::Headquarters
The ISO 3166 country and subdivision codes for the partner's headquarters location.
-
#industry_segments ⇒ Array<String>
The industry segments or verticals that the partner serves.
-
#localized_contents ⇒ Array<Types::LocalizedContent>
A list of localized content versions for different languages and regions.
-
#logo_url ⇒ String
The URL to the partner's logo image.
-
#primary_solution_type ⇒ String
The primary type of solution or service the partner provides.
-
#profile_id ⇒ String
The unique identifier of the partner profile.
-
#translation_source_locale ⇒ String
The source locale used for automatic translation of profile content.
-
#website_url ⇒ String
The partner's primary website URL.
Instance Attribute Details
#description ⇒ String
A description of the partner's business, services, and capabilities.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The public display name for the partner organization.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#headquarters ⇒ Types::Headquarters
The ISO 3166 country and subdivision codes for the partner's headquarters location. If no headquarters location is set, this field is not included in the response.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#industry_segments ⇒ Array<String>
The industry segments or verticals that the partner serves.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#localized_contents ⇒ Array<Types::LocalizedContent>
A list of localized content versions for different languages and regions.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#logo_url ⇒ String
The URL to the partner's logo image.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#primary_solution_type ⇒ String
The primary type of solution or service the partner provides.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of the partner profile.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#translation_source_locale ⇒ String
The source locale used for automatic translation of profile content.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |
#website_url ⇒ String
The partner's primary website URL.
2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2123 class PartnerProfile < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters, :profile_id) SENSITIVE = [] include Aws::Structure end |