Class: Aws::PartnerCentralAccount::Types::PutAllianceLeadContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::PutAllianceLeadContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:email_verification_code]
Instance Attribute Summary collapse
-
#alliance_lead_contact ⇒ Types::AllianceLeadContact
The alliance lead contact information to set for the partner account.
-
#catalog ⇒ String
The catalog identifier for the partner account.
-
#email_verification_code ⇒ String
The verification code sent to the alliance lead contact's email to confirm the update.
-
#identifier ⇒ String
The unique identifier of the partner account.
Instance Attribute Details
#alliance_lead_contact ⇒ Types::AllianceLeadContact
The alliance lead contact information to set for the partner account.
2182 2183 2184 2185 2186 2187 2188 2189 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2182 class PutAllianceLeadContactRequest < Struct.new( :catalog, :identifier, :alliance_lead_contact, :email_verification_code) SENSITIVE = [:email_verification_code] include Aws::Structure end |
#catalog ⇒ String
The catalog identifier for the partner account.
2182 2183 2184 2185 2186 2187 2188 2189 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2182 class PutAllianceLeadContactRequest < Struct.new( :catalog, :identifier, :alliance_lead_contact, :email_verification_code) SENSITIVE = [:email_verification_code] include Aws::Structure end |
#email_verification_code ⇒ String
The verification code sent to the alliance lead contact's email to confirm the update.
2182 2183 2184 2185 2186 2187 2188 2189 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2182 class PutAllianceLeadContactRequest < Struct.new( :catalog, :identifier, :alliance_lead_contact, :email_verification_code) SENSITIVE = [:email_verification_code] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the partner account.
2182 2183 2184 2185 2186 2187 2188 2189 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2182 class PutAllianceLeadContactRequest < Struct.new( :catalog, :identifier, :alliance_lead_contact, :email_verification_code) SENSITIVE = [:email_verification_code] include Aws::Structure end |