Class: Aws::PartnerCentralAccount::Types::ResourceNotFoundException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralaccount/types.rb

Overview

The specified resource could not be found. This may occur when referencing a resource that does not exist or has been deleted.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2455

class ResourceNotFoundException < Struct.new(
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The specific reason why the resource was not found.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2455

class ResourceNotFoundException < Struct.new(
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end