Class: Aws::PartnerCentralAccount::Types::SendEmailVerificationCodeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::SendEmailVerificationCodeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
The catalog identifier for the partner account.
-
#email ⇒ String
The email address to send the verification code to.
Instance Attribute Details
#catalog ⇒ String
The catalog identifier for the partner account.
2492 2493 2494 2495 2496 2497 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2492 class SendEmailVerificationCodeRequest < Struct.new( :catalog, :email) SENSITIVE = [] include Aws::Structure end |
#email ⇒ String
The email address to send the verification code to.
2492 2493 2494 2495 2496 2497 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2492 class SendEmailVerificationCodeRequest < Struct.new( :catalog, :email) SENSITIVE = [] include Aws::Structure end |