Class: Aws::PartnerCentralAccount::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralaccount/types.rb

Overview

The request was rejected because it would exceed a service quota or limit. This may occur when trying to create more resources than allowed by the service limits.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2516

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The specific reason for the service quota being exceeded.

Returns:

  • (String)


2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2516

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end