Class: Aws::PartnerCentralAccount::Types::StartQualificationsDisassociationTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::StartQualificationsDisassociationTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies your partner resource.
-
#associated_partner ⇒ Types::QualificationsAssociationPartner
The resolved primary partner's profile and account identifiers that the task is disassociating qualifications from.
-
#catalog ⇒ String
The catalog identifier echoed from the request.
-
#id ⇒ String
Your unique partner identifier in the AWS Partner Network.
-
#started_at ⇒ Time
The timestamp when the qualifications disassociation task started, in ISO 8601 format.
-
#status ⇒ String
The current status of the qualifications disassociation task.
-
#task_id ⇒ String
The unique identifier of the started qualifications disassociation task, in the format
pqdtask-[a-z2-7]{13}.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies your partner resource.
2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2795 class StartQualificationsDisassociationTaskResponse < Struct.new( :catalog, :arn, :id, :task_id, :status, :associated_partner, :started_at) SENSITIVE = [] include Aws::Structure end |
#associated_partner ⇒ Types::QualificationsAssociationPartner
The resolved primary partner's profile and account identifiers that the task is disassociating qualifications from.
2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2795 class StartQualificationsDisassociationTaskResponse < Struct.new( :catalog, :arn, :id, :task_id, :status, :associated_partner, :started_at) SENSITIVE = [] include Aws::Structure end |
#catalog ⇒ String
The catalog identifier echoed from the request.
2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2795 class StartQualificationsDisassociationTaskResponse < Struct.new( :catalog, :arn, :id, :task_id, :status, :associated_partner, :started_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Your unique partner identifier in the AWS Partner Network.
2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2795 class StartQualificationsDisassociationTaskResponse < Struct.new( :catalog, :arn, :id, :task_id, :status, :associated_partner, :started_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the qualifications disassociation task started, in ISO 8601 format.
2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2795 class StartQualificationsDisassociationTaskResponse < Struct.new( :catalog, :arn, :id, :task_id, :status, :associated_partner, :started_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the qualifications disassociation task. The
initial value is IN_PROGRESS.
2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2795 class StartQualificationsDisassociationTaskResponse < Struct.new( :catalog, :arn, :id, :task_id, :status, :associated_partner, :started_at) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the started qualifications disassociation
task, in the format pqdtask-[a-z2-7]{13}.
2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2795 class StartQualificationsDisassociationTaskResponse < Struct.new( :catalog, :arn, :id, :task_id, :status, :associated_partner, :started_at) SENSITIVE = [] include Aws::Structure end |