Class: Aws::PartnerCentralAccount::Types::StartVerificationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::StartVerificationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp when the verification process was completed.
-
#started_at ⇒ Time
The timestamp when the verification process was successfully initiated.
-
#verification_response_details ⇒ Types::VerificationResponseDetails
Initial response details specific to the type of verification started, which may include next steps or additional requirements.
-
#verification_status ⇒ String
The initial status of the verification process after it has been started.
-
#verification_status_reason ⇒ String
Additional information about the initial verification status, including any immediate feedback about the submitted verification details.
-
#verification_type ⇒ String
The type of verification that was started based on the provided verification details.
Instance Attribute Details
#completed_at ⇒ Time
The timestamp when the verification process was completed. This field is typically null for newly started verifications unless they complete immediately.
2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2834 class StartVerificationResponse < Struct.new( :verification_type, :verification_status, :verification_status_reason, :verification_response_details, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the verification process was successfully initiated.
2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2834 class StartVerificationResponse < Struct.new( :verification_type, :verification_status, :verification_status_reason, :verification_response_details, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#verification_response_details ⇒ Types::VerificationResponseDetails
Initial response details specific to the type of verification started, which may include next steps or additional requirements.
2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2834 class StartVerificationResponse < Struct.new( :verification_type, :verification_status, :verification_status_reason, :verification_response_details, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#verification_status ⇒ String
The initial status of the verification process after it has been started. Typically this will be pending or in-progress.
2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2834 class StartVerificationResponse < Struct.new( :verification_type, :verification_status, :verification_status_reason, :verification_response_details, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#verification_status_reason ⇒ String
Additional information about the initial verification status, including any immediate feedback about the submitted verification details.
2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2834 class StartVerificationResponse < Struct.new( :verification_type, :verification_status, :verification_status_reason, :verification_response_details, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#verification_type ⇒ String
The type of verification that was started based on the provided verification details.
2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2834 class StartVerificationResponse < Struct.new( :verification_type, :verification_status, :verification_status_reason, :verification_response_details, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |