Class: Aws::PartnerCentralAccount::Types::TaskDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::TaskDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Contains detailed information about a profile update task including the changes to be made.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The updated description for the partner profile.
-
#display_name ⇒ String
The updated display name for the partner profile.
-
#headquarters ⇒ Types::Headquarters
The ISO 3166 country and subdivision codes for the partner's headquarters location.
-
#industry_segments ⇒ Array<String>
The updated industry segments for the partner profile.
-
#localized_contents ⇒ Array<Types::LocalizedContent>
The updated localized content for the partner profile.
-
#logo_url ⇒ String
The updated logo URL for the partner profile.
-
#primary_solution_type ⇒ String
The updated primary solution type for the partner profile.
-
#translation_source_locale ⇒ String
The updated translation source locale for the partner profile.
-
#website_url ⇒ String
The updated website URL for the partner profile.
Instance Attribute Details
#description ⇒ String
The updated description for the partner profile.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The updated display name for the partner profile.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |
#headquarters ⇒ Types::Headquarters
The ISO 3166 country and subdivision codes for the partner's headquarters location. If you omit this field, the service retains the existing headquarters value.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |
#industry_segments ⇒ Array<String>
The updated industry segments for the partner profile.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |
#localized_contents ⇒ Array<Types::LocalizedContent>
The updated localized content for the partner profile.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |
#logo_url ⇒ String
The updated logo URL for the partner profile.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |
#primary_solution_type ⇒ String
The updated primary solution type for the partner profile.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |
#translation_source_locale ⇒ String
The updated translation source locale for the partner profile.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |
#website_url ⇒ String
The updated website URL for the partner profile.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2961 class TaskDetails < Struct.new( :display_name, :description, :website_url, :logo_url, :primary_solution_type, :industry_segments, :translation_source_locale, :localized_contents, :headquarters) SENSITIVE = [] include Aws::Structure end |