Class: Aws::PartnerCentralAccount::Types::UpdateConnectionPreferencesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::UpdateConnectionPreferencesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_type ⇒ String
The access type setting for connections (e.g., open, restricted, invitation-only).
-
#catalog ⇒ String
The catalog identifier for the partner account.
-
#excluded_participant_identifiers ⇒ Array<String>
The updated list of participant identifiers to exclude from connections.
-
#revision ⇒ Integer
The revision number of the connection preferences for optimistic locking.
Instance Attribute Details
#access_type ⇒ String
The access type setting for connections (e.g., open, restricted, invitation-only).
3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3004 class UpdateConnectionPreferencesRequest < Struct.new( :catalog, :revision, :access_type, :excluded_participant_identifiers) SENSITIVE = [] include Aws::Structure end |
#catalog ⇒ String
The catalog identifier for the partner account.
3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3004 class UpdateConnectionPreferencesRequest < Struct.new( :catalog, :revision, :access_type, :excluded_participant_identifiers) SENSITIVE = [] include Aws::Structure end |
#excluded_participant_identifiers ⇒ Array<String>
The updated list of participant identifiers to exclude from connections.
3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3004 class UpdateConnectionPreferencesRequest < Struct.new( :catalog, :revision, :access_type, :excluded_participant_identifiers) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ Integer
The revision number of the connection preferences for optimistic locking.
3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3004 class UpdateConnectionPreferencesRequest < Struct.new( :catalog, :revision, :access_type, :excluded_participant_identifiers) SENSITIVE = [] include Aws::Structure end |