Class: Aws::PartnerCentralAccount::Types::UpdateConnectionPreferencesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralaccount/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_type ⇒ String

The updated access type setting for connections.

Returns:

  • (String)


3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3079

class UpdateConnectionPreferencesResponse < Struct.new(
  :catalog,
  :arn,
  :access_type,
  :excluded_participant_ids,
  :updated_at,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

The Amazon Resource Name (ARN) of the updated connection preferences.

Returns:

  • (String)


3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3079

class UpdateConnectionPreferencesResponse < Struct.new(
  :catalog,
  :arn,
  :access_type,
  :excluded_participant_ids,
  :updated_at,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#catalog ⇒ String

The catalog identifier for the partner account.

Returns:

  • (String)


3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3079

class UpdateConnectionPreferencesResponse < Struct.new(
  :catalog,
  :arn,
  :access_type,
  :excluded_participant_ids,
  :updated_at,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#excluded_participant_ids ⇒ Array<String>

A list of participant IDs that are excluded from connection requests or interactions.

Returns:

  • (Array<String>)


3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3079

class UpdateConnectionPreferencesResponse < Struct.new(
  :catalog,
  :arn,
  :access_type,
  :excluded_participant_ids,
  :updated_at,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#revision ⇒ Integer

The updated revision number of the connection preferences.

Returns:

  • (Integer)


3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3079

class UpdateConnectionPreferencesResponse < Struct.new(
  :catalog,
  :arn,
  :access_type,
  :excluded_participant_ids,
  :updated_at,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The timestamp when the connection preferences were last updated.

Returns:

  • (Time)


3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 3079

class UpdateConnectionPreferencesResponse < Struct.new(
  :catalog,
  :arn,
  :access_type,
  :excluded_participant_ids,
  :updated_at,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end