Class: Aws::PartnerCentralAccount::Types::ErrorDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::ErrorDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Contains detailed information about an error that occurred during an operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#locale ⇒ String
The locale or language code for the error message.
-
#message ⇒ String
A human-readable description of the error.
-
#reason ⇒ String
A machine-readable code or reason for the error.
Instance Attribute Details
#locale ⇒ String
The locale or language code for the error message.
1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1026 class ErrorDetail < Struct.new( :locale, :message, :reason) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A human-readable description of the error.
1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1026 class ErrorDetail < Struct.new( :locale, :message, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A machine-readable code or reason for the error.
1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1026 class ErrorDetail < Struct.new( :locale, :message, :reason) SENSITIVE = [] include Aws::Structure end |