Class: Aws::PartnerCentralAccount::Types::ListConnectionInvitationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::ListConnectionInvitationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
The catalog identifier for the partner account.
-
#connection_type ⇒ String
Filter results by connection type (e.g., reseller, distributor, technology partner).
-
#max_results ⇒ Integer
The maximum number of connection invitations to return in a single response.
-
#next_token ⇒ String
The token for retrieving the next page of results in paginated responses.
-
#other_participant_identifiers ⇒ Array<String>
Filter results by specific participant identifiers.
-
#participant_type ⇒ String
Filter results by participant type (inviter or invitee).
-
#status ⇒ String
Filter results by invitation status (pending, accepted, rejected, canceled, expired).
Instance Attribute Details
#catalog ⇒ String
The catalog identifier for the partner account.
1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835 class ListConnectionInvitationsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers, :participant_type, :status) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
Filter results by connection type (e.g., reseller, distributor, technology partner).
1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835 class ListConnectionInvitationsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers, :participant_type, :status) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of connection invitations to return in a single response.
1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835 class ListConnectionInvitationsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers, :participant_type, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results in paginated responses.
1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835 class ListConnectionInvitationsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers, :participant_type, :status) SENSITIVE = [] include Aws::Structure end |
#other_participant_identifiers ⇒ Array<String>
Filter results by specific participant identifiers.
1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835 class ListConnectionInvitationsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers, :participant_type, :status) SENSITIVE = [] include Aws::Structure end |
#participant_type ⇒ String
Filter results by participant type (inviter or invitee).
1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835 class ListConnectionInvitationsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers, :participant_type, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filter results by invitation status (pending, accepted, rejected, canceled, expired).
1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1835 class ListConnectionInvitationsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers, :participant_type, :status) SENSITIVE = [] include Aws::Structure end |