Class: Aws::PartnerCentralAccount::Types::ListConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralAccount::Types::ListConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
The catalog identifier for the partner account.
-
#connection_type ⇒ String
Filter results by connection type (e.g., reseller, distributor, technology partner).
-
#max_results ⇒ Integer
The maximum number of connections to return in a single response.
-
#next_token ⇒ String
The token for retrieving the next page of results in paginated responses.
-
#other_participant_identifiers ⇒ Array<String>
Filter results by specific participant identifiers.
Instance Attribute Details
#catalog ⇒ String
The catalog identifier for the partner account.
1890 1891 1892 1893 1894 1895 1896 1897 1898 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1890 class ListConnectionsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
Filter results by connection type (e.g., reseller, distributor, technology partner).
1890 1891 1892 1893 1894 1895 1896 1897 1898 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1890 class ListConnectionsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of connections to return in a single response.
1890 1891 1892 1893 1894 1895 1896 1897 1898 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1890 class ListConnectionsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results in paginated responses.
1890 1891 1892 1893 1894 1895 1896 1897 1898 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1890 class ListConnectionsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers) SENSITIVE = [] include Aws::Structure end |
#other_participant_identifiers ⇒ Array<String>
Filter results by specific participant identifiers.
1890 1891 1892 1893 1894 1895 1896 1897 1898 |
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 1890 class ListConnectionsRequest < Struct.new( :catalog, :next_token, :connection_type, :max_results, :other_participant_identifiers) SENSITIVE = [] include Aws::Structure end |