Class: Aws::PartnerCentralAccount::Types::RegistrantVerificationDetails Private
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::PartnerCentralAccount::Types::RegistrantVerificationDetails
- Defined in:
- lib/aws-sdk-partnercentralaccount/types.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Contains the personal information required for verifying an individual’s identity as part of the partner registration process in AWS Partner Central.