Class: Aws::PartnerCentralAccount::Types::TaskDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralaccount/types.rb

Overview

Contains detailed information about a profile update task including the changes to be made.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The updated description for the partner profile.

Returns:

  • (String)


2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2924

class TaskDetails < Struct.new(
  :display_name,
  :description,
  :website_url,
  :logo_url,
  :primary_solution_type,
  :industry_segments,
  :translation_source_locale,
  :localized_contents)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The updated display name for the partner profile.

Returns:

  • (String)


2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2924

class TaskDetails < Struct.new(
  :display_name,
  :description,
  :website_url,
  :logo_url,
  :primary_solution_type,
  :industry_segments,
  :translation_source_locale,
  :localized_contents)
  SENSITIVE = []
  include Aws::Structure
end

#industry_segmentsArray<String>

The updated industry segments for the partner profile.

Returns:

  • (Array<String>)


2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2924

class TaskDetails < Struct.new(
  :display_name,
  :description,
  :website_url,
  :logo_url,
  :primary_solution_type,
  :industry_segments,
  :translation_source_locale,
  :localized_contents)
  SENSITIVE = []
  include Aws::Structure
end

#localized_contentsArray<Types::LocalizedContent>

The updated localized content for the partner profile.

Returns:



2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2924

class TaskDetails < Struct.new(
  :display_name,
  :description,
  :website_url,
  :logo_url,
  :primary_solution_type,
  :industry_segments,
  :translation_source_locale,
  :localized_contents)
  SENSITIVE = []
  include Aws::Structure
end

#logo_urlString

The updated logo URL for the partner profile.

Returns:

  • (String)


2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2924

class TaskDetails < Struct.new(
  :display_name,
  :description,
  :website_url,
  :logo_url,
  :primary_solution_type,
  :industry_segments,
  :translation_source_locale,
  :localized_contents)
  SENSITIVE = []
  include Aws::Structure
end

#primary_solution_typeString

The updated primary solution type for the partner profile.

Returns:

  • (String)


2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2924

class TaskDetails < Struct.new(
  :display_name,
  :description,
  :website_url,
  :logo_url,
  :primary_solution_type,
  :industry_segments,
  :translation_source_locale,
  :localized_contents)
  SENSITIVE = []
  include Aws::Structure
end

#translation_source_localeString

The updated translation source locale for the partner profile.

Returns:

  • (String)


2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2924

class TaskDetails < Struct.new(
  :display_name,
  :description,
  :website_url,
  :logo_url,
  :primary_solution_type,
  :industry_segments,
  :translation_source_locale,
  :localized_contents)
  SENSITIVE = []
  include Aws::Structure
end

#website_urlString

The updated website URL for the partner profile.

Returns:

  • (String)


2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/aws-sdk-partnercentralaccount/types.rb', line 2924

class TaskDetails < Struct.new(
  :display_name,
  :description,
  :website_url,
  :logo_url,
  :primary_solution_type,
  :industry_segments,
  :translation_source_locale,
  :localized_contents)
  SENSITIVE = []
  include Aws::Structure
end